@@ -303,7 +303,9 @@ bool FlatpakReferencesModel::isDefaults(int index) const
     return true;
 }
 
-const QVector<FlatpakReference *> &FlatpakReferencesModel::references() const
+const QList<FlatpakReference *> &FlatpakReferencesModel::references() const
 {
     return m_references;
 }
+
+#include "moc_flatpakreference.cpp"
