@@ -9,13 +9,23 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <QFile>
+#include <algorithm>
 
 K_PLUGIN_CLASS_WITH_JSON(KCMFlatpak, "kcm_flatpak.json")
 
 KCMFlatpak::KCMFlatpak(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, data, args)
+    : KQuickManagedConfigModule(parent, data)
     , m_refsModel(new FlatpakReferencesModel(this))
 {
+    QString requestedReference;
+    if (args.count() > 0) {
+        const QVariant &arg0 = args.at(0);
+        if (arg0.canConvert<QString>()) {
+            const QString arg0str = arg0.toString();
+            requestedReference = arg0str;
+        }
+    }
+
     constexpr const char *uri = "org.kde.plasma.kcm.flatpakpermissions";
 
     qmlRegisterUncreatableType<KCMFlatpak>(uri, 1, 0, "KCMFlatpak", QString());
@@ -25,6 +35,18 @@ KCMFlatpak::KCMFlatpak(QObject *parent, const KPluginMetaData &data, const QVari
 
     connect(m_refsModel, &FlatpakReferencesModel::needsLoad, this, &KCMFlatpak::load);
     connect(m_refsModel, &FlatpakReferencesModel::settingsChanged, this, &KCMFlatpak::settingsChanged);
+
+    if (!requestedReference.isEmpty()) {
+        const auto &refs = m_refsModel->references();
+        const auto it = std::find_if(refs.constBegin(), refs.constEnd(), [&](FlatpakReference *ref) {
+            return ref->ref() == requestedReference;
+        });
+        if (it != refs.constEnd()) {
+            const auto index = std::distance(refs.constBegin(), it);
+            m_index = index;
+        }
+    }
+
     settingsChanged(); // Initialize Reset & Defaults buttons
 }
 
@@ -66,3 +88,5 @@ int KCMFlatpak::currentIndex() const
 }
 
 #include "kcm.moc"
+
+#include "moc_kcm.cpp"
